Edge

Struct Edge 

pub struct Edge {
    pub kind: EdgeKind,
    pub from: PortId,
    pub to: PortId,
    pub hidden: bool,
    pub selectable: Option<bool>,
    pub focusable: Option<bool>,
    pub interaction_width: Option<f32>,
    pub deletable: Option<bool>,
    pub reconnectable: Option<EdgeReconnectable>,
}
Edge between two ports.

Fields

kind: EdgeKind

Edge kind.

from: PortId

Source port.

to: PortId

Target port.

hidden: bool

Whether the edge is hidden (XyFlow edge.hidden).

Hidden edges are excluded from derived selection and rendering surfaces.

selectable: Option<bool>

Whether the edge can be selected (XyFlow edge.selectable).

When omitted, the global NodeGraphInteractionState.edges_selectable decides.

focusable: Option<bool>

Whether the edge can receive keyboard focus (XyFlow edge.focusable).

When omitted, the global NodeGraphInteractionState.edges_focusable decides.

interaction_width: Option<f32>

Optional edge hit-test interaction width in logical pixels (XyFlow edge.interactionWidth).

When omitted, the global NodeGraphInteractionState.edge_interaction_width decides.

deletable: Option<bool>

Whether the edge can be deleted via editor interactions (XyFlow edge.deletable).

When omitted, the global NodeGraphInteractionState.edges_deletable decides.

reconnectable: Option<EdgeReconnectable>

Whether the edge can be reconnected via editor interactions (XyFlow edge.reconnectable).

In XyFlow this field is a boolean | 'source' | 'target'. true enables reconnecting both endpoints, 'source' only enables reconnecting the source endpoint and 'target' only enables reconnecting the target endpoint.

When omitted, the global NodeGraphInteractionState.edges_reconnectable decides.