Graph

Struct Graph 

pub struct Graph {
    pub graph_id: GraphId,
    pub graph_version: u32,
    pub imports: BTreeMap<GraphId, GraphImport>,
    pub symbols: BTreeMap<SymbolId, Symbol>,
    pub nodes: BTreeMap<NodeId, Node>,
    pub ports: BTreeMap<PortId, Port>,
    pub edges: BTreeMap<EdgeId, Edge>,
    pub groups: BTreeMap<GroupId, Group>,
    pub sticky_notes: BTreeMap<StickyNoteId, StickyNote>,
    pub bindings: BTreeMap<BindingId, Binding>,
}
Node graph document.

Fields

graph_id: GraphId

Stable identity for editor-state lookup and cross-graph references.

graph_version: u32

Schema version for migrations.

imports: BTreeMap<GraphId, GraphImport>

Transitive graph dependencies (semantic subgraphs / libraries).

symbols: BTreeMap<SymbolId, Symbol>

Graph-scoped symbols (blackboard/variables).

nodes: BTreeMap<NodeId, Node>

Node instances.

ports: BTreeMap<PortId, Port>

Port instances (owned by nodes, but stored in a flat map for stable lookup).

edges: BTreeMap<EdgeId, Edge>

Edges between ports.

groups: BTreeMap<GroupId, Group>

Optional groups.

sticky_notes: BTreeMap<StickyNoteId, StickyNote>

Optional sticky notes.

bindings: BTreeMap<BindingId, Binding>

Optional knowledge-canvas bindings.

Implementations

Source

impl Graph

pub fn new(graph_id: GraphId) -> Self

Creates a new, empty graph with the given id.

Examples found in repository?
examples/build_graph.rs (line 34)
32fn main() {
33    let node_id = NodeId::from_u128(2);
34    let mut graph = Graph::new(GraphId::from_u128(1));
35
36    let mut tx = GraphTransaction::new().with_label("add source node");
37    tx.push(GraphOp::AddNode {
38        id: node_id,
39        node: make_node("demo.source", 10.0, 20.0),
40    });
41    tx.apply_to(&mut graph).expect("transaction applies");
42
43    assert_eq!(graph.nodes.len(), 1);
44    assert_eq!(graph.nodes[&node_id].kind, NodeKindKey::new("demo.source"));
45}