pub struct GraphImport {
pub alias: Option<String>,
}Expand description
Reserved metadata for a graph import.
The presence of an entry declares a dependency from the importing graph onto the imported graph. Additional metadata (aliasing, pinning, namespaces) can be added later without changing the key contract.
Fields
alias: Option<String>Optional import alias for UI and authoring ergonomics.