GraphHistory

Struct GraphHistory 

pub struct GraphHistory { /* private fields */ }
A simple undo/redo history for committed graph transactions.

Implementations

Source

impl GraphHistory

pub fn new(limit: usize) -> Self

pub fn clear(&mut self)

pub fn can_undo(&self) -> bool

pub fn can_redo(&self) -> bool

pub fn undo_len(&self) -> usize

pub fn redo_len(&self) -> usize

pub fn record(&mut self, tx: GraphTransaction)

Records a committed transaction (original + derived concretization ops).

pub fn undo<E>( &mut self, apply: impl FnMut(&GraphTransaction) -> Result<GraphTransaction, E>, ) -> Result<bool, E>

Undoes the last recorded transaction by applying its inverse transaction.

The apply closure is responsible for applying the transaction to the graph and returning the committed transaction (including any derived ops produced by the profile pipeline).

pub fn redo<E>( &mut self, apply: impl FnMut(&GraphTransaction) -> Result<GraphTransaction, E>, ) -> Result<bool, E>

Redoes the last undone transaction.